# coding: utf-8

import datetime
from django import forms
from django.forms.util import ErrorDict
from django.utils.translation import ugettext as _
from jmb.core.admin.options import JumboActionForm
from jmb.core.forms import DateTimePicker


class EventActionForm(JumboActionForm):
    send_from_date = forms.DateTimeField(required=False, widget=DateTimePicker)
    send_to_date = forms.DateTimeField(required=False, widget=DateTimePicker)

    def clean(self):
        cleaned_data = super(EventActionForm, self).clean()
        send_from = cleaned_data.get('send_from_date', False)
        send_to = cleaned_data.get('send_to_date', False)
        if bool(send_from) != bool(send_to):
            raise forms.ValidationError(
                _(u"I campi data devono essere entrambi valorizzati o nulli")
            )
        if send_from and send_to:
            if send_from >= send_to:
                raise forms.ValidationError(
                    _(u"La data di inizio deve essere successiva a quella di fine")
                )
            if send_from <= datetime.datetime.now():
                raise forms.ValidationError(
                    _(u"La data di inizio non può essere precedente a quella attuale")
                )
        return cleaned_data

    def full_clean(self):
        """
        Sovrascritto per non perdere il clean data, che di default in django 1.4 viene cancellato se sono
        presenti errori. Ciò per garantire compatibilità col jmb.core
        """
        self._errors = ErrorDict()
        if not self.is_bound: # Stop further processing.
            return
        self.cleaned_data = {}
        if self.empty_permitted and not self.has_changed():
            return
        self._clean_fields()
        self._clean_form()
        self._post_clean()

