# -*- coding: utf-8 -*-
from django.conf import settings
from django.db import models
from django.utils.translation import ugettext as _

from jmb.core.db.models import DateModel, UserModel
from jmb.core.db.cmsmodels import StatusModel

from cms.models.pluginmodel import CMSPlugin


# Root class to inherit
class AbstractSettings(CMSPlugin, DateModel, UserModel,  StatusModel):
    invite_status_to_be_visible = models.IntegerField(
        choices=settings.ACOMEA_EVENT_INVITE_STATUS_CODES,
        null=True, blank=True,
        verbose_name=_('Invite status to be visible')
    )

    def __unicode__(self):
        return "%s %s" % (
            ('On - ' if self.status else 'Off - '),
            self.template_name
        )

    class Meta:
        app_label = "event"
        abstract = True


# AdhesionSettings class
class AdhesionSettings(AbstractSettings):
    template_name = models.CharField(
        _("Template"),
        max_length=100,
        choices=settings.ACOMEA_EVENT_CMSPLUGIN_ADHESION_TEMPLATES,
        default="event/cms_plugins/adhesion.html"
    )
    form = models.CharField(
        _("Form"),
        max_length=100,
        choices=settings.ACOMEA_EVENT_CMSPLUGIN_ADHESION_CLASSES,
        default="acomea.event.cms.forms.AdhesionForm",
    )

    @property
    def invite_step_to_be_visible(self):
        return "adhesion"


# GreetingsSettings class
class GreetingsSettings(AbstractSettings):
    template_name = models.CharField(
        _("Template"),
        max_length=100,
        choices=settings.ACOMEA_EVENT_CMSPLUGIN_GREETINGS_TEMPLATES,
        default="event/cms_plugins/greetings.html"
    )
    form = models.CharField(
        _("Form"),
        max_length=100,
        choices=settings.ACOMEA_EVENT_CMSPLUGIN_GREETINGS_CLASSES,
        default="acomea.event.cms.forms.GreetingsForm",
    )

    @property
    def invite_step_to_be_visible(self):
        return "greetings"


class HeaderImageSettings(AbstractSettings):
    width = models.CharField(
        _("width"),
        max_length=10,
        default="100%"
    )
    height = models.CharField(
        _("height"),
        max_length=10,
        default="100%"
    )

    def __unicode__(self):
        return "%s header image" % ('On - ' if self.status else 'Off - ')


class TitleSettings(AbstractSettings):
    def __unicode__(self):
        return "%s title" % ('On - ' if self.status else 'Off - ')
