# -*- coding: utf-8 -*-

import logging

from django.contrib import admin
from django.http import HttpRequest
from jmb.async.models import Task
from django.utils.translation import ugettext_lazy as _

from jmb.async.tasks import JmbJobtasticTask

from acomea.event.utils import resend_event_invites, send_event_reminder

logger = logging.getLogger('celery.task')


class SendReminderTask(JmbJobtasticTask):
    task_name = _("Send reminder")
    significant_kwargs = []
    herd_avoidance_timeout = 0
    cache_duration = -1

    def calculate_result(
            self, model=None, pks=None, select_across=None,
            get=None, req=None, event=None, test=None, check_can_create=True,
            date_from=None, date_to=None
    ):

        logger.info('Sending invite xtastic')
        admin.autodiscover()
        modeladmin = admin.site._registry[model]
        request = HttpRequest()
        request.GET = get
        request.REQUEST = req
        if select_across:
            qs = modeladmin.queryset(request)
        else:
            qs = modeladmin.model.objects.filter(id__in=pks)
        ##########################################################################
        created = 0
        events = qs.filter(status=1).exclude()
        n_of_steps = events.count()
        for count, event in enumerate(events):
            event_sending_values = send_event_reminder(
                event, test=test, is_task=True, request=request, check_can_create=check_can_create,
                date_from=date_from, date_to=date_to
            )
            created += event_sending_values["created"]
            self.update_progress(
                count,
                n_of_steps,
                update_frequency=100,
            )
        ##########################################################################
        task_id = self.request.id
        task = Task.objects.get(task_id=task_id)
        msg = 'Sent reminder to %s contacts' % created
        if not check_can_create:
            msg += " (NO CONTROLS)"
        task.message = msg
        task.save()
        return {'message': msg}


class ReSendInvitesTask(JmbJobtasticTask):
    task_name = _("Resend invite")
    significant_kwargs = []
    herd_avoidance_timeout = 0
    cache_duration = -1

    def calculate_result(
            self, model=None, pks=None, select_across=None,
            get=None, req=None, event=None, test=None, check_can_create=True,
            date_from=None, date_to=None):
        logger.info('Resending invite xtastic')
        admin.autodiscover()
        modeladmin = admin.site._registry[model]
        request = HttpRequest()
        request.GET = get
        request.REQUEST = req
        if select_across:
            qs = modeladmin.queryset(request)
        else:
            qs = modeladmin.model.objects.filter(id__in=pks)
        ##########################################################################
        created = 0
        events = qs.filter(status=1).exclude()
        n_of_steps = events.count()
        for count, event in enumerate(events):
            event_sending_values = resend_event_invites(
                event, test=test, is_task=True, request=request,
                check_can_create=check_can_create,
                date_from=date_from, date_to=date_to
            )
            created += event_sending_values["created"]
            self.update_progress(
                count,
                n_of_steps,
                update_frequency=100,
            )
        ##########################################################################
        task_id = self.request.id
        task = Task.objects.get(task_id=task_id)
        msg = 'Resent invite to %s contacts' % created
        if not check_can_create:
            msg += " (NO CONTROLS)"
        task.message = msg
        task.save()
        return {'message': msg}