# -*- coding: utf-8 -*-

from django.conf import settings

from jmb.mailer.sender import Mailer
from acomea.contact.utils.mailer import render_template_from_string


def resend_event_invites(
        event, test=False, is_task=True, request=None, check_can_create=True,
        date_from=None, date_to=None
    ):
    sent_in_test = 0
    created = 0
    not_created = 0
    for invite in event.invites.filter(status__isnull=True):
        mailer = Mailer(invite, test, is_task=is_task, request=request)
        adhesion = event.translations.get(
            language__id=event.default_language.id,
        )
        description = render_template_from_string(
            dict(contact=invite.contact, invite=invite, is_email=True),
            adhesion.body
        )
        context = dict(description=description, invite=invite)
        if adhesion.body_image:
            context["top_image_url"] = "%s://%s/%s" % (
                settings.PROFILO_TCP_PROTOCOL,
                settings.PROFILO_HOST,
                adhesion.body_image.url.lstrip("/")
            )
        mail_created, email_object = mailer.create_message(
            invite.contact, context, check_can_create=check_can_create,
            date_from=date_from, date_to=date_to
        )
        if mail_created:
            created += 1
            if test:
                mailer.send(email_object)
                sent_in_test += 1
        else:
            not_created += 1
    return dict(sent_in_test=sent_in_test, created=created, not_created=not_created)


def send_event_reminder(
        event, test=False, is_task=True, request=None, check_can_create=True,
        contact_emails=None, date_from=None, date_to=None):
    sent_in_test = 0
    created = 0
    not_created = 0
    event_reminder = event.reminder_translations.get(
        language__id=event.default_language.id,
    )

    if contact_emails:
        queryset = event.invites.filter(
            status=settings.ACOMEA_EVENT_INVITE_ACCEPTED,
            contact__emails__email__in=contact_emails
        )
    else:
        queryset = event.invites.filter(status=settings.ACOMEA_EVENT_INVITE_ACCEPTED)

    for invite in queryset:
        mailer = Mailer(invite, test, is_task=is_task, request=request, is_reminder=True)
        contact = invite.contact
        description = render_template_from_string(
            dict(
                contact=contact,
                invite=invite,
                is_email=True
            ),
            event_reminder.body
        )
        context = dict(
            description=description,
            invite=invite,
        )
        if event_reminder.body_image:
            context["top_image_url"] = "%s://%s/%s" % (
                settings.PROFILO_TCP_PROTOCOL,
                settings.PROFILO_HOST,
                event_reminder.body_image.url.lstrip("/")
            )
        mail_created, email_object = mailer.create_message(
            contact, context, check_can_create=check_can_create,
            date_from=date_from, date_to=date_to
        )
        if mail_created:
            created += 1
            if test:
                mailer.send(email_object)
                sent_in_test += 1
                invite.sent = True
                invite.save()
        else:
            not_created += 1
    return dict(sent_in_test=sent_in_test, created=created, not_created=not_created)